@@ -115,19 +115,35 @@ class Context(object):
         return l 
             
     #------------------------------------------------------------------------
-    def new_node(self,uid,label,u):
+    def new_node(self,uid,label,u,df):
         """
         Return a new ``Node`` unless one with the same uid exists
         
         """
+        
+        # Prior to v1.3.5, degrees of freedom was not buffered in a Node.
+        # Now, to maintain backward comparability, a value ``None`` 
+        # will be inserted for backward compatibility when needed.
+        # See the ``shim_1_3_3`` function in archive.py.        
+
         if uid in self._registered_intermediate_nodes:
-            raise RuntimeError(
-                "intermediate node uid({}), '{}', u={} is used".format(
-                    uid,label,u
-                )
+            # If the node found is indistinguishable from the new node 
+            # then quietly ignore the request 
+            n = self._registered_intermediate_nodes[uid]
+            
+            OK = (
+                label == n.label and 
+                u == n.u and 
+                df == n.df 
             )
+            if not OK:
+                raise RuntimeError(
+                    "intermediate node uid({}), '{}', u={}, df={} is used".format(
+                        uid,label,u,df
+                    )
+                )
         else:          
-            n = Node(uid,label,u)
+            n = Node(uid,label,u,df)
             self._registered_intermediate_nodes[uid] = n
 
         return n
