@@ -3,6 +3,8 @@ from __future__ import division
 import math
 import cmath
 import numbers
+import warnings
+
 try:
     from itertools import izip  # Python 2
 except ImportError:
@@ -437,7 +439,7 @@ def result(un,label=None):
     The component of uncertainty, or the sensitivity, of an uncertain number 
     with respect to an intermediate result can be evaluated. 
 
-    Declaring intermediate results also enables the dependencies of uncertain 
+    Declaring intermediate results also enables uncertain 
     numbers to be stored in an archive.
         
     .. note::
@@ -463,8 +465,18 @@ def result(un,label=None):
     """
     if hasattr(un,'_intermediate'):
         return un._intermediate(label)
+        
     elif isinstance(un,numbers.Complex):
+        # This covers any pure number type
+        if label is not None:
+            warnings.warn(
+                "A label cannot be applied to a pure number by result():"
+                " the label {!r} has been ignored".format(label),
+                RuntimeWarning
+            )
+        
         return un
+        
     else:
         raise TypeError(
             "undefined for {!r}'".format(un)
@@ -616,7 +628,7 @@ def multiple_ucomplex(x_seq,u_seq,df,label_seq=None):
         
         >>> z = v * exp(phi)/ i
         >>> print(z)
-        (127.732(70)+219.847(296)j)
+        (+127.732(70)+219.847(296)j)
         >>> z.r
         -0.591484610818998...
 
