@@ -1,9 +1,11 @@
 import re
 import unittest
+import numbers
+import sys
 
-try:
+if sys.version_info[0] < 3:
     from operator import div  # Python 2
-except ImportError:
+else:
     from operator import truediv as div
 
 import numpy
@@ -2555,7 +2557,7 @@ class TestStringRepresentations(unittest.TestCase):
             inf,
             None,True
         )
-        self.assertEqual( str(z), '(inf(inf)+inf(inf)j)')
+        self.assertEqual( str(z), '(+inf(inf)+inf(inf)j)')
         self.assertEqual( repr(z), 'ucomplex((inf+infj), u=[inf,inf], r=nan, df=inf)')
         
         z = UncertainComplex._elementary(
@@ -2565,7 +2567,7 @@ class TestStringRepresentations(unittest.TestCase):
             nan,
             None,True
         )
-        self.assertEqual( str(z), '(inf(inf)+inf(inf)j)')
+        self.assertEqual( str(z), '(+inf(inf)+inf(inf)j)')
         self.assertEqual( repr(z), 'ucomplex((inf+infj), u=[inf,inf], r=nan, df=nan)')
 
         z = UncertainComplex._elementary(
@@ -2575,7 +2577,7 @@ class TestStringRepresentations(unittest.TestCase):
             nan,
             None,True
         )
-        self.assertEqual( str(z), '(inf(inf)+inf(nan)j)')
+        self.assertEqual( str(z), '(+inf(inf)+inf(nan)j)')
         self.assertEqual( repr(z), 'ucomplex((inf+infj), u=[inf,nan], r=nan, df=nan)')
 
         z = UncertainComplex._elementary(
@@ -2585,7 +2587,7 @@ class TestStringRepresentations(unittest.TestCase):
             nan,
             None,True
         )
-        self.assertEqual( str(z), '(inf(nan)+inf(nan)j)')
+        self.assertEqual( str(z), '(+inf(nan)+inf(nan)j)')
         self.assertEqual( repr(z), 'ucomplex((inf+infj), u=[nan,nan], r=nan, df=nan)')
 
         z = UncertainComplex._elementary(
@@ -2595,7 +2597,7 @@ class TestStringRepresentations(unittest.TestCase):
             nan,
             None,True
         )
-        self.assertEqual( str(z), '(inf(nan)+nan(nan)j)')
+        self.assertEqual( str(z), '(+inf(nan)+nan(nan)j)')
         self.assertEqual( repr(z), 'ucomplex((inf+nanj), u=[nan,nan], r=nan, df=nan)')
 
         z = UncertainComplex._elementary(
@@ -2605,7 +2607,7 @@ class TestStringRepresentations(unittest.TestCase):
             nan,
             None,True
         )
-        self.assertEqual( str(z), '(nan(nan)+nan(nan)j)')
+        self.assertEqual( str(z), '(+nan(nan)+nan(nan)j)')
         self.assertEqual( repr(z), 'ucomplex((nan+nanj), u=[nan,nan], r=nan, df=nan)')
 
         z = UncertainComplex._elementary(
@@ -2615,7 +2617,7 @@ class TestStringRepresentations(unittest.TestCase):
             nan,
             None,True
         )
-        self.assertEqual( str(z), '(1.00(10)+1.00(10)j)')
+        self.assertEqual( str(z), '(+1.00(10)+1.00(10)j)')
         self.assertEqual( repr(z), 'ucomplex((1+1j), u=[0.1,0.1], r=0.0, df=nan)')
 
 #-----------------------------------------------------
@@ -2655,6 +2657,13 @@ class TestMisc(unittest.TestCase):
             )
         )
 
+    def test_intermediate_constant(self):
+        self.assertTrue( equivalent_complex( result(1+3j), 1+3j) )
+        self.assertTrue( isinstance( result(1+3j), numbers.Complex) )
+        if sys.version_info[0] > 2:
+            x = self.assertWarns( RuntimeWarning, result,(1+3j),label='error')
+            x = self.assertWarns( RuntimeWarning, result,1,label='error')
+        
 #============================================================================
 if(__name__== '__main__'):
 
